# CHANGELOG



## v0.2.0 (2024-01-08)

### Feature

* feat: support python &gt;=3.9 (#28)

feat: support python &gt;=3.9

Fixes #27

feat: support python &gt;=3.9

Fixes #27

misc.

misc.

misc. ([`61d9402`](https://github.com/MartinBernstorff/herbarium/commit/61d9402f6601fbe85c6a6c2bec04d6211a4f8007))


## v0.1.0 (2024-01-07)

### Ci

* ci: fix release pipeline ([`e28c77c`](https://github.com/MartinBernstorff/herbarium/commit/e28c77ca98d35733ae3309265bc8d73d6ca9afe5))

* ci: setup release to pypi (#24)

ci: setup release to pypi

Fixes #21

ci: setup release to pypi

Fixes #21

tests: get tests running

misc.

ci: setup release.yml ([`3106412`](https://github.com/MartinBernstorff/herbarium/commit/3106412b885c832f12feaa75c1dc5d16c0088292))

### Feature

* feat: add GithubIssueService

Fixes #8. ([`c2939c3`](https://github.com/MartinBernstorff/herbarium/commit/c2939c3e12247e255293837076643fd6ae811451))

### Unknown

* misc. ([`79f4f2d`](https://github.com/MartinBernstorff/herbarium/commit/79f4f2df5ae0960c0ef15fb96f18ea30eb1eafc5))

* misc. ([`3ad9517`](https://github.com/MartinBernstorff/herbarium/commit/3ad95172a8addfe265cca73cef58c9ee69e5eae2))

* dev: create github cli dir on devcontainer init ([`58c40e6`](https://github.com/MartinBernstorff/herbarium/commit/58c40e6f34e14a1192a6ff177a53f5f417825ab8))

* misc. ([`8de39ac`](https://github.com/MartinBernstorff/herbarium/commit/8de39ac6cb6d45ab0c7066fa18553a4b7a2bade3))

* $feat: pretty cli animations with typer/rich (#23)

$feat: pretty cli animations with typer/rich

Fixes #13

$feat: pretty cli animations with typer/rich

Fixes #13

misc.

misc. ([`830040c`](https://github.com/MartinBernstorff/herbarium/commit/830040c8ec929215791ec495332ebefcc1eca7bd))

* dev: clean up gitignore (#22)

Fixes #19 ([`a58c808`](https://github.com/MartinBernstorff/herbarium/commit/a58c808497b99ee460ad38e840ed658a1a2d93f9))

* $fix: misc. types (#17)

$fix: misc. types

Fixes #14

$fix: misc. types

Fixes #14

refactor: cleanup

misc. ([`4342005`](https://github.com/MartinBernstorff/herbarium/commit/43420050f810d0bad2e6b85708d6d4449140e1c4))

* misc. ([`9d6b6de`](https://github.com/MartinBernstorff/herbarium/commit/9d6b6ded5bd4a56f0fa2f4731c65ef02d4e32ad1))

* Update README.md (#12) ([`f2d76a0`](https://github.com/MartinBernstorff/herbarium/commit/f2d76a05372650b192b47205bca60a3803549762))

* first commit ([`5af600e`](https://github.com/MartinBernstorff/herbarium/commit/5af600e2b31b082b6785271c806243553de5e7bf))
